@@ -21,9 +21,8 @@ coef.sc_plm <- function(object, ...) {
 coef.sc_hplm <- function(object, casewise = FALSE, ...) {
   if (casewise) {
     out <- coef(object$hplm)
-    names(out) <- .plm.row.names(names(out), object)
-    out <- cbind(Case = row.names(out), out)
-    row.names(out) <- NULL
+    names(out) <- rename_predictors(names(out), object)
+    out <- rownames_to_first_column(out, "Case")
     return(out)
   } else {
     summary(object$hplm)$tTable
